@@ -212,6 +212,29 @@ class FixedRateBond(BaseModel):
         return  v
 
 
+class StructuredBond(BaseModel):
+    issue_date: Optional[str] = None
+    maturity: str
+    settings: BondSetting
+    structure: List[Structure] = []
+
+    @validator('maturity')
+    def valid_maturity(cls, v): 
+        try:
+            adate = dt64(v)
+        except:
+            raise ValueError
+        return  v
+
+    @validator('issue_date')
+    def valid_issue_date(cls, v): 
+        try:
+            adate = dt64(v)
+        except:
+            raise ValueError
+        return  v
+
+
 class CouponInspector(BaseModel):
     previous_coupon_rate: float
     next_coupon_rate: float 
@@ -232,13 +255,12 @@ class CashFlowInspector(BaseModel):
 
 
 class BondRisk(BaseModel):
-    accrued: float
-    accrued_period: float
-    clean_price: float
-    bps: float
-    duration: float
-    modified_duration: float
-    convexity: float
-    basis_point_value: float
-    yield_value_basis_point: float
+    accrued: Optional[float] = None
+    clean_price: Optional[float] = None
+    bps: Optional[float] = None
+    duration: Optional[float] = None
+    modified_duration: Optional[float] = None
+    convexity: Optional[float] = None
+    basis_point_value: Optional[float] = None
+    yield_value_basis_point: Optional[float] = None
     
