@@ -11,15 +11,14 @@ def curve_piecewise(value_date: str,
                 depo_rates: List[Rate], 
                 par_setting:BondSetting, 
                 par_rates: List[Rate], 
-                country = None, 
+                cal = None, 
+               
                 method: PiecewiseMethods = PiecewiseMethods.logcubicdiscount):
     
     vdate = datestr_to_qldate(value_date) 
     ql.Settings.instance().evaluationDate = vdate
-    if not country:
+    if not cal:
         calendar = ql.WeekendsOnly()
-    elif country in ql_calendar_market.keys():
-        calendar = ql_calendar_market[country]
     else:
         calendar = ql.WeekendsOnly()
     
@@ -52,7 +51,7 @@ def curve_piecewise(value_date: str,
         t_structure = ql.PiecewiseLogCubicDiscount(vdate,
                                                 rate_helpers,
                                                 ql_day_count[par_setting.day_count])
-
+    #return the term structure
     return t_structure
 
 
@@ -137,7 +136,7 @@ def calc_curve(value_date: str,
     return zero_set, df_set
     
 
-
+    
     
     
     
